# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: pit/envelope/v1/envelope.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'pit/envelope/v1/envelope.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1epit/envelope/v1/envelope.proto\x12\x0fpit.envelope.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xac\x02\n\rEventEnvelope\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12*\n\x02ts\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02ts\x12\x10\n\x03key\x18\x03 \x01(\tR\x03key\x12\x16\n\x06tenant\x18\x04 \x01(\tR\x06tenant\x12\x16\n\x06series\x18\x05 \x01(\tR\x06series\x12\x12\n\x04\x63\x65ll\x18\x06 \x01(\tR\x04\x63\x65ll\x12\x1a\n\x08producer\x18\x07 \x01(\tR\x08producer\x12!\n\x0cpayload_type\x18\x08 \x01(\tR\x0bpayloadType\x12\x18\n\x07payload\x18\t \x01(\x0cR\x07payload\x12%\n\x0epayload_sha256\x18\n \x01(\tR\rpayloadSha256B\xcb\x01\n\x13\x63om.pit.envelope.v1B\rEnvelopeProtoP\x01ZGgithub.com/awesomelyradical/pit-proto/gen/go/pit/envelope/v1;envelopev1\xa2\x02\x03PEX\xaa\x02\x0fPit.Envelope.V1\xca\x02\x0fPit\\Envelope\\V1\xe2\x02\x1bPit\\Envelope\\V1\\GPBMetadata\xea\x02\x11Pit::Envelope::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pit.envelope.v1.envelope_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.pit.envelope.v1B\rEnvelopeProtoP\001ZGgithub.com/awesomelyradical/pit-proto/gen/go/pit/envelope/v1;envelopev1\242\002\003PEX\252\002\017Pit.Envelope.V1\312\002\017Pit\\Envelope\\V1\342\002\033Pit\\Envelope\\V1\\GPBMetadata\352\002\021Pit::Envelope::V1'
  _globals['_EVENTENVELOPE']._serialized_start=85
  _globals['_EVENTENVELOPE']._serialized_end=385
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: pit/events/v1/events.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'pit/events/v1/events.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1apit/events/v1/events.proto\x12\rpit.events.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"2\n\x08KeyValue\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value\"\xa5\x03\n\x0eTradeFillEvent\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12*\n\x02ts\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02ts\x12\x1b\n\ttenant_id\x18\x03 \x01(\tR\x08tenantId\x12\x1b\n\tseries_id\x18\x04 \x01(\tR\x08seriesId\x12\x17\n\x07\x63\x65ll_id\x18\x05 \x01(\tR\x06\x63\x65llId\x12\x14\n\x05venue\x18\x06 \x01(\tR\x05venue\x12\x1e\n\ninstrument\x18\x07 \x01(\tR\ninstrument\x12\x19\n\x08order_id\x18\x08 \x01(\tR\x07orderId\x12!\n\x0cstrategy_ref\x18\t \x01(\tR\x0bstrategyRef\x12\x10\n\x03qty\x18\n \x01(\x01R\x03qty\x12\x14\n\x05price\x18\x0b \x01(\x01R\x05price\x12\x17\n\x07\x66\x65\x65_usd\x18\x0c \x01(\x01R\x06\x66\x65\x65Usd\x12!\n\x0cslippage_bps\x18\r \x01(\x01R\x0bslippageBps\x12!\n\x0cnotional_usd\x18\x0e \x01(\x01R\x0bnotionalUsd\"\xc3\x02\n\x0eNAVUpdateEvent\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12*\n\x02ts\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02ts\x12\x1b\n\ttenant_id\x18\x03 \x01(\tR\x08tenantId\x12\x1b\n\tseries_id\x18\x04 \x01(\tR\x08seriesId\x12\x17\n\x07\x63\x65ll_id\x18\x05 \x01(\tR\x06\x63\x65llId\x12\x17\n\x07nav_usd\x18\x06 \x01(\x01R\x06navUsd\x12&\n\x0f\x63\x61sh_liquid_usd\x18\x07 \x01(\x01R\rcashLiquidUsd\x12,\n\x12unrealized_pnl_usd\x18\x08 \x01(\x01R\x10unrealizedPnlUsd\x12(\n\x10realized_pnl_usd\x18\t \x01(\x01R\x0erealizedPnlUsd\"\xc4\x03\n\x15\x45xposureSnapshotEvent\x12\x19\n\x08\x65vent_id\x18\x01 \x01(\tR\x07\x65ventId\x12*\n\x02ts\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02ts\x12\x1b\n\ttenant_id\x18\x03 \x01(\tR\x08tenantId\x12\x1b\n\tseries_id\x18\x04 \x01(\tR\x08seriesId\x12\x17\n\x07\x63\x65ll_id\x18\x05 \x01(\tR\x06\x63\x65llId\x12,\n\x12gross_exposure_usd\x18\x06 \x01(\x01R\x10grossExposureUsd\x12(\n\x10net_exposure_usd\x18\x07 \x01(\x01R\x0enetExposureUsd\x12@\n\x0f\x66\x61\x63tor_exposure\x18\x08 \x03(\x0b\x32\x17.pit.events.v1.KeyValueR\x0e\x66\x61\x63torExposure\x12=\n\x0evenue_conc_pct\x18\t \x03(\x0b\x32\x17.pit.events.v1.KeyValueR\x0cvenueConcPct\x12\x38\n\x0bliq_metrics\x18\n \x03(\x0b\x32\x17.pit.events.v1.KeyValueR\nliqMetricsB\xbb\x01\n\x11\x63om.pit.events.v1B\x0b\x45ventsProtoP\x01ZCgithub.com/awesomelyradical/pit-proto/gen/go/pit/events/v1;eventsv1\xa2\x02\x03PEX\xaa\x02\rPit.Events.V1\xca\x02\rPit\\Events\\V1\xe2\x02\x19Pit\\Events\\V1\\GPBMetadata\xea\x02\x0fPit::Events::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'pit.events.v1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.pit.events.v1B\013EventsProtoP\001ZCgithub.com/awesomelyradical/pit-proto/gen/go/pit/events/v1;eventsv1\242\002\003PEX\252\002\rPit.Events.V1\312\002\rPit\\Events\\V1\342\002\031Pit\\Events\\V1\\GPBMetadata\352\002\017Pit::Events::V1'
  _globals['_KEYVALUE']._serialized_start=78
  _globals['_KEYVALUE']._serialized_end=128
  _globals['_TRADEFILLEVENT']._serialized_start=131
  _globals['_TRADEFILLEVENT']._serialized_end=552
  _globals['_NAVUPDATEEVENT']._serialized_start=555
  _globals['_NAVUPDATEEVENT']._serialized_end=878
  _globals['_EXPOSURESNAPSHOTEVENT']._serialized_start=881
  _globals['_EXPOSURESNAPSHOTEVENT']._serialized_end=1333
# @@protoc_insertion_point(module_scope)
